<?php
/**
 * This source file is proprietary and part of Rebilly.
 *
 * (c) Rebilly SRL
 *     Rebilly Ltd.
 *     Rebilly Inc.
 *
 * @see https://www.rebilly.com
 */

declare(strict_types=1);

namespace Rebilly\Wp\Member\Action;

// Exit if accessed directly.
if (!defined('ABSPATH')) {
    exit();
}

class Action
{
    /** @var array|string[] */
    protected static $actions = [
        Subscribe::class,
        SubscriptionCancel::class,
        SubscriptionsPaginate::class,
        InvoicesPaginate::class,
        InvoiceDownload::class,
        CardAdd::class,
        CardUpdate::class,
        CardDeactivate::class,
        Login::class,
    ];

    /** @var array|AjaxAction[] */
    protected static $actionInstances = [];

    public static function register(): void
    {
        do_action('rebilly_before_actions');
        foreach (static::$actions as $action) {
            $obj = new $action();
            if ($obj instanceof AjaxAction) {
                static::$actionInstances[$obj->getName()] = $obj;
            }
        }
        do_action('rebilly_after_actions');
    }

    public static function get(string $name): ?AjaxAction
    {
        return static::$actionInstances[$name] ?? null;
    }
}
