<?php
/**
 * This source file is proprietary and part of Rebilly.
 *
 * (c) Rebilly SRL
 *     Rebilly Ltd.
 *     Rebilly Inc.
 *
 * @see https://www.rebilly.com
 */

declare(strict_types=1);

namespace Rebilly\Wp\Member\Api;

use Exception;
use Rebilly\Entities\Customer;
use Rebilly\Http\Exception\UnprocessableEntityException;
use Rebilly\Rest\Collection;

// Exit if accessed directly.
if (!defined('ABSPATH')) {
    exit();
}

/**
 * Class CustomerService
 * @package Rebilly\Wp\Member\Api
 */
class CustomerService extends Service
{
    /**
     * @param string $id
     *
     * @return Customer|null
     */
    public function get(string $id): ?Customer
    {
        if (!blank($id)) {
            try {
                return $this->api()
                    ->customers()
                    ->load($id);
            } catch (Exception $e) {
            }
        }

        return null;
    }

    /**
     * @param string $email
     *
     * @return Customer[]|Collection
     */
    public function findByEmail(string $email): Collection
    {
        try {
            return $this->api()
                ->customers()
                ->search([
                    'filter' => "email:$email",
                ]);
        } catch (Exception $ex) {
        }

        return new Collection(new Customer());
    }

    /**
     * @param Customer|array $data
     *
     * @throws UnprocessableEntityException
     * @return Customer|null
     */
    public function create($data): ?Customer
    {
        try {
            return $this->api()
                ->customers()
                ->create($data);
        } catch (Exception $ex) {
            if ($ex instanceof UnprocessableEntityException) {
                throw $ex;
            }
        }

        return null;
    }

    /**
     * @param $tokenId
     *
     * @throws UnprocessableEntityException
     * @return Customer|null
     */
    public function createFromToken($tokenId): ?Customer
    {
        try {
            return $this->create(
                (new Customer())
                    ->setPaymentToken($tokenId)
            );
        } catch (Exception $ex) {
            if ($ex instanceof UnprocessableEntityException) {
                throw $ex;
            }
        }

        return null;
    }

    /**
     * @param string $id
     * @param Customer|array $data
     *
     * @throws UnprocessableEntityException
     * @return Customer|null
     */
    public function update(string $id, $data): ?Customer
    {
        try {
            return $this->api()
                ->customers()
                ->update($id, $data);
        } catch (Exception $ex) {
            if ($ex instanceof UnprocessableEntityException) {
                throw $ex;
            }
        }

        return null;
    }
}
