<?php
/**
 * This source file is proprietary and part of Rebilly.
 *
 * (c) Rebilly SRL
 *     Rebilly Ltd.
 *     Rebilly Inc.
 *
 * @see https://www.rebilly.com
 */

declare(strict_types=1);

namespace Rebilly\Wp\Member\Api;

use Exception;
use Rebilly\Entities\Invoice;
use Rebilly\Entities\InvoiceItem;
use Rebilly\Rest\Collection;
use Rebilly\Rest\File;

// Exit if accessed directly.
if (!defined('ABSPATH')) {
    exit();
}

/**
 * Class InvoiceService
 * @package Rebilly\Wp\Member\Api
 */
class InvoiceService extends Service
{
    /**
     * @param string $id
     *
     * @return Invoice|null
     */
    public function get(string $id): ?Invoice
    {
        if (!blank($id)) {
            try {
                return $this->api()
                    ->invoices()
                    ->load($id);
            } catch (Exception $ex) {
            }
        }

        return null;
    }

    /**
     * @param string $id
     *
     * @return File|null
     */
    public function getPdf(string $id): ?File
    {
        if (!blank($id)) {
            try {
                return $this->api()
                    ->invoices()
                    ->loadPdf($id);
            } catch (Exception $ex) {
            }
        }

        return null;
    }

    /**
     * @param array $params
     *
     * @return Invoice[]|Collection
     */
    public function find(array $params = []): Collection
    {
        try {
            return $this->api()
                ->invoices()
                ->search($params);
        } catch (Exception $ex) {
        }

        return new Collection(new Invoice());
    }

    /**
     * @param string $customerId
     * @param string $subscriptionId
     * @param int $page
     * @param int $perPage
     *
     * @return Invoice[]|Collection
     */
    public function findByCustomer(string $customerId, string $subscriptionId = '', int $page = 1, int $perPage = 10): Collection
    {
        $filter = "customerId:$customerId;websiteId:{$this->getWebsiteId()}";
        if (strlen($subscriptionId) !== 0) {
            $filter .= ";subscriptionId:$subscriptionId";
        }

        return $this->find([
            'filter' => $filter,
            'sort' => '-createdTime',
            'limit' => $perPage,
            'offset' => $perPage * ($page - 1),
        ]);
    }

    /**
     * @param string $invoiceId
     * @param array $params
     *
     * @return InvoiceItem[]|Collection
     */
    public function findItems(string $invoiceId, array $params = []): Collection
    {
        try {
            return $this->api()
                ->invoiceItems()
                ->search($invoiceId, $params);
        } catch (Exception $ex) {
        }

        return new Collection(new InvoiceItem());
    }
}
