<?php
/**
 * This source file is proprietary and part of Rebilly.
 *
 * (c) Rebilly SRL
 *     Rebilly Ltd.
 *     Rebilly Inc.
 *
 * @see https://www.rebilly.com
 */

declare(strict_types=1);

namespace Rebilly\Wp\Member\Api\Middleware;

use Psr\Http\Message\RequestInterface as Request;
use Psr\Http\Message\ResponseInterface as Response;
use Rebilly\Client;
use Rebilly\Middleware;

// Exit if accessed directly.
if (!defined('ABSPATH')) {
    exit();
}

class UserAgent implements Middleware
{
    /**
     * {@inheritdoc}
     */
    public function __invoke(Request $request, Response $response, callable $next)
    {
        global $wp_version;
        $release = @php_uname('r') ?: 'unknown';
        $machine = @php_uname('m') ?: 'unknown';

        return $next($request->withHeader(
            'User-Agent',
            self::generateUserAgentName(
                'PHP-SDK',
                Client::SDK_VERSION,
                [
                    'wp-ver=' . $wp_version,
                    'wp-plugin-ver=' . REBILLY_WP_VERSION,
                    'platform-ver=' . PHP_VERSION,
                    'os=' . str_replace(' ', '_', PHP_OS . ' ' . $release),
                    'machine=' . $machine,
                ]
            )
        ), $response);
    }

    /**
     * Generate User-Agent header value.
     *
     * @param string $name
     * @param string $version
     * @param array $features
     *
     * @return string
     */
    private static function generateUserAgentName($name, $version, array $features): string
    {
        return sprintf('RebillyWP/%s %s (%s)', $name, $version, implode('; ', $features));
    }
}
