<?php
/**
 * This source file is proprietary and part of Rebilly.
 *
 * (c) Rebilly SRL
 *     Rebilly Ltd.
 *     Rebilly Inc.
 *
 * @see https://www.rebilly.com
 */

declare(strict_types=1);

namespace Rebilly\Wp\Member\Api;

use Exception;
use Rebilly\Entities\Plan;
use Rebilly\Rest\Collection;

// Exit if accessed directly.
if (!defined('ABSPATH')) {
    exit();
}

/**
 * Class PlanService
 * @package Rebilly\Wp\Member\Api
 */
class PlanService extends Service
{
    /**
     * @param array $ids
     * @param bool $only
     *
     * @return Plan[]|Collection
     */
    public function all(array $ids = [], bool $only = false): Collection
    {
        $params = [];
        if (count($ids) > 0 || $only === true) {
            $params['filter'] = 'id:' . implode(',', $ids);
        }

        try {
            return $this->api()
                ->plans()
                ->search($params);
        } catch (Exception $ex) {
        }

        return new Collection(new Plan());
    }

    /**
     * @param array $ids
     * @param bool $withProduct
     * @param bool $only
     *
     * @return string[]|array
     */
    public function allNames(array $ids = [], bool $withProduct = true, bool $only = false): array
    {
        $plans = [];
        $products = [];
        $plansRaw = $this->all($ids, $only);
        if ($withProduct) {
            $productIds = [];
            foreach ($plansRaw as $plan) {
                $productIds[] = $plan->getProductId();
            }
            $productsRaw = $this->client->product()->all($productIds, true);
            foreach ($productsRaw as $product) {
                $products[$product->getId()] = $product;
            }
        }

        foreach ($plansRaw as $plan) {
            $plans[$plan->getId()] = $withProduct && isset($products[$plan->getProductId()]) ?
                $products[$plan->getProductId()]->getName() . ' (' . $plan->getName() . ')' :
                $plan->getName();
        }

        asort($plans);

        return $plans;
    }
}
