<?php
/**
 * This source file is proprietary and part of Rebilly.
 *
 * (c) Rebilly SRL
 *     Rebilly Ltd.
 *     Rebilly Inc.
 *
 * @see https://www.rebilly.com
 */

declare(strict_types=1);

namespace Rebilly\Wp\Member\Api;

use Rebilly\Client as Api;

// Exit if accessed directly.
if (!defined('ABSPATH')) {
    exit();
}

/**
 * Class Service
 * @package Rebilly\Wp\Member\Api
 */
abstract class Service
{
    /** @var Client */
    protected $client;

    /**
     * Service constructor.
     * @param Client $client
     */
    public function __construct(Client $client)
    {
        $this->client = $client;
    }

    /**
     * @return Api
     */
    protected function api(): Api
    {
        return $this->client->api();
    }

    /**
     * @return string
     */
    protected function getWebsiteId(): string
    {
        return $this->client->getWebsiteId();
    }

    /**
     * @param string $key
     * @param callable|null $callback
     * @param int $expires
     * @param bool $force
     *
     * @return bool|mixed
     */
    protected function cached(string $key, ?callable $callback, int $expires = 0, bool $force = false)
    {
        $transient = "rebilly__api__{$key}";
        if ($callback === null || $force) {
            delete_transient($key);
            if ($callback === null) {
                return true;
            }
        }

        $value = get_transient($transient);
        if ($value === false) {
            $value = call_user_func($callback);
            set_transient($transient, $value, $expires);
        }

        return $value;
    }
}
