<?php
/**
 * This source file is proprietary and part of Rebilly.
 *
 * (c) Rebilly SRL
 *     Rebilly Ltd.
 *     Rebilly Inc.
 *
 * @see https://www.rebilly.com
 */

declare(strict_types=1);

namespace Rebilly\Wp\Member\Api;

use Exception;
use Rebilly\Entities\Transaction;
use Rebilly\Http\Exception\UnprocessableEntityException;

// Exit if accessed directly.
if (!defined('ABSPATH')) {
    exit();
}

/**
 * Class TransactionService
 * @package Rebilly\Wp\Member\Api
 */
class TransactionService extends Service
{
    /**
     * @param string $id
     *
     * @return TransactionService|null
     */
    public function get(string $id): ?Transaction
    {
        if (!blank($id)) {
            try {
                return $this->api()
                    ->transactions()
                    ->load($id);
            } catch (Exception $ex) {
            }
        }

        return null;
    }

    /**
     * @param Transaction|array $data
     *
     * @throws UnprocessableEntityException
     * @return Transaction|null
     */
    public function create($data): ?Transaction
    {
        try {
            return $this->api()
                ->transactions()
                ->create($data);
        } catch (Exception $ex) {
            if ($ex instanceof UnprocessableEntityException) {
                throw $ex;
            }
        }

        return null;
    }
}
