<?php
/**
 * This source file is proprietary and part of Rebilly.
 *
 * (c) Rebilly SRL
 *     Rebilly Ltd.
 *     Rebilly Inc.
 *
 * @see https://www.rebilly.com
 */

declare(strict_types=1);

namespace Rebilly\Wp\Member\Api;

use Exception;
use Rebilly\Entities\Webhook;
use Rebilly\Entities\WebhookCredential;
use Rebilly\Http\Exception\UnprocessableEntityException;

// Exit if accessed directly.
if (!defined('ABSPATH')) {
    exit();
}

/**
 * Class WebhookService
 * @package Rebilly\Wp\Member\Api
 */
class WebhookService extends Service
{
    /**
     * @param string $id
     *
     * @return Webhook|null
     */
    public function get(string $id): ?Webhook
    {
        try {
            return $this->api()
                ->webhooks()
                ->load($id);
        } catch (Exception $ex) {
        }

        return null;
    }

    /**
     * @param Webhook|array $data
     *
     * @throws UnprocessableEntityException
     * @return Webhook|null
     */
    public function create($data): ?Webhook
    {
        try {
            return $this->api()
                ->webhooks()
                ->create($data);
        } catch (Exception $ex) {
            if ($ex instanceof UnprocessableEntityException) {
                throw $ex;
            }
        }

        return null;
    }

    /**
     * @param WebhookCredential|array $data
     *
     * @throws UnprocessableEntityException
     * @return WebhookCredential|null
     */
    public function createCredential($data): ?WebhookCredential
    {
        try {
            return $this->api()
                ->webhookCredentials()
                ->create($data);
        } catch (Exception $ex) {
            if ($ex instanceof UnprocessableEntityException) {
                throw $ex;
            }
        }

        return null;
    }

    /**
     * @param string $id
     * @param Webhook|array $data
     *
     * @throws UnprocessableEntityException
     * @return Webhook|null
     */
    public function update(string $id, $data): ?Webhook
    {
        try {
            return $this->api()
                ->webhooks()
                ->update($id, $data);
        } catch (Exception $ex) {
            if ($ex instanceof UnprocessableEntityException) {
                throw $ex;
            }
        }

        return null;
    }
}
