<?php
/**
 * This source file is proprietary and part of Rebilly.
 *
 * (c) Rebilly SRL
 *     Rebilly Ltd.
 *     Rebilly Inc.
 *
 * @see https://www.rebilly.com
 */

declare(strict_types=1);

namespace Rebilly\Wp\Member\Integration;

use Elementor\Plugin;
use Exception;
use Rebilly\Wp\Member\Integration\Elementor\DynamicPageWidget;
use Rebilly\Wp\Member\Integration\Elementor\FormWidget;
use Rebilly\Wp\Member\Integration\Elementor\PortalWidget;

// Exit if accessed directly.
if (!defined('ABSPATH')) {
    exit();
}

class Elementor implements IntegrationContract
{
    public static function isApplicable(): bool
    {
        return did_action('elementor/loaded') > 0;
    }

    public function register(): void
    {
        add_action('elementor/widgets/widgets_registered', [$this, 'initWidgets']);
    }

    /**
     * @throws Exception
     */
    public function initWidgets(): void
    {
        Plugin::instance()->widgets_manager->register_widget_type(new FormWidget());
        Plugin::instance()->widgets_manager->register_widget_type(new DynamicPageWidget());
        Plugin::instance()->widgets_manager->register_widget_type(new PortalWidget());
    }
}
