<?php
/**
 * This source file is proprietary and part of Rebilly.
 *
 * (c) Rebilly SRL
 *     Rebilly Ltd.
 *     Rebilly Inc.
 *
 * @see https://www.rebilly.com
 */

declare(strict_types=1);

namespace Rebilly\Wp\Member\Integration\SiteOrigin;

use Rebilly\Wp\Member\Entity\Form;
use SiteOrigin_Widget;

// Exit if accessed directly.
if (!defined('ABSPATH')) {
    exit();
}

class FormWidget extends SiteOrigin_Widget
{
    protected static $forms = null;

    public function __construct()
    {
        parent::__construct(
            'rebilly_form',
            __('Rebilly Form', REBILLY_WP_LANG_DOMAIN),
            [
                'description' => __('Insert a Rebilly form on your page', REBILLY_WP_LANG_DOMAIN),
                'panels_icon' => 'dashicons dashicons-forms',
                'panels_groups' => ['rebilly'],
            ],
            [],
            [
                'formId' => [
                    'type' => 'select',
                    'label' => __('Form', REBILLY_WP_LANG_DOMAIN),
                    'default' => '',
                    'prompt' => __('Select a Form', REBILLY_WP_LANG_DOMAIN),
                    'input_css_classes' => ['widefat'],
                    'options' => static::getForms(),
                ],
                'condition' => [
                    'type' => 'select',
                    'label' => __('Condition', REBILLY_WP_LANG_DOMAIN),
                    'default' => '',
                    'input_css_classes' => ['widefat'],
                    'options' => static::getConditions(),
                ],
            ]
        );
        add_action('siteorigin_widgets_render_preview_' . $this->id_base, [$this, 'enqueueStyles']);
        add_filter('siteorigin_widgets_template_file_' . $this->id_base, [$this, 'getTemplateFile']);
    }

    public function enqueueStyles(): void
    {
        wp_enqueue_style('wp_rebilly_m-front', REBILLY_WP_URL . 'dist/css/front.css', [], '1.0.0');
    }

    public function getTemplateFile(): string
    {
        return REBILLY_WP_DIR . 'template/admin/integration/siteorigin/form.php';
    }

    public static function getForms(): array
    {
        if (static::$forms === null) {
            $formsRaw = Form::all() ?? [];
            static::$forms = [];
            foreach ($formsRaw as $form) {
                static::$forms[$form->ID] = get_the_title($form);
            }
        }

        return static::$forms;
    }

    public static function getConditions(): array
    {
        return [
            '' => __('Display for all', REBILLY_WP_LANG_DOMAIN),
            'only:auth' => __('Members only', REBILLY_WP_LANG_DOMAIN),
            'only:guest' => __('Guests only', REBILLY_WP_LANG_DOMAIN),
        ];
    }
}
