<?php
/**
 * This source file is proprietary and part of Rebilly.
 *
 * (c) Rebilly SRL
 *     Rebilly Ltd.
 *     Rebilly Inc.
 *
 * @see https://www.rebilly.com
 */

declare(strict_types=1);

namespace Rebilly\Wp\Member\Reformer\Traits;

// Exit if accessed directly.
use Rebilly\Wp\Member\Reformer\Node;

if (!defined('ABSPATH')) {
    exit();
}

trait HasDomRenderer
{
    /**
     * @param array $env
     *
     * @return string
     */
    public function render(array $env): string
    {
        if (!$this->isAvailable($env)) {
            return '';
        }

        [$tag, $attributesRaw, $inner] = [$this->getTag(), $this->getAttributes(), $this->renderInner($env)];

        // Filter empty ones
        $attributesRaw = array_filter($attributesRaw, function ($value) {
            return !blank($value);
        });

        // Compile attributes
        $attributes = implode(' ', array_map(function ($keyRaw, $valueRaw) {
            [$key, $value] = [esc_attr($keyRaw), esc_attr($valueRaw)];

            return "$key=\"$value\"";
        }, array_keys($attributesRaw), $attributesRaw));

        return "<$tag $attributes>$inner</$tag>";
    }

    /**
     * @param array $env
     *
     * @return string
     */
    public function renderInner(array $env): string
    {
        $inner = '';
        foreach ($this->getChildren() as $child) {
            /** @var Node $child */
            $inner .= $child->render($env);
        }

        return $inner;
    }
}
