<?php
/**
 * This source file is proprietary and part of Rebilly.
 *
 * (c) Rebilly SRL
 *     Rebilly Ltd.
 *     Rebilly Inc.
 *
 * @see https://www.rebilly.com
 */

declare(strict_types=1);

namespace Rebilly\Wp\Member\Shortcode;

use Rebilly\Wp\Member\Action\Action;
use Rebilly\Wp\Member\Entity\User;

// Exit if accessed directly.
if (!defined('ABSPATH')) {
    exit();
}

class DynamicPage implements ShortcodeContract
{
    public const NAME = 'rebilly_page';

    public const PAGE_SUBSCRIPTIONS = 'subscriptions';

    public const PAGE_INVOICES = 'invoices';

    public const PAGE_LOGIN = 'login';

    /**
     * @return string
     */
    public static function getName(): string
    {
        return self::NAME;
    }

    /**
     * @param array|string $attrs
     * @return string
     */
    public function render($attrs = []): string
    {
        $pageId = is_array($attrs) ? ($attrs[0] ?? '') : $attrs;
        if (blank($pageId) || !($page = $this->getPage($pageId))) {
            $name = self::getName();

            return __("Use shortcode [{$name} {page type}] with valid page type", REBILLY_WP_LANG_DOMAIN);
        }

        $user = User::find();
        $action = Action::get($page['action'] ?? '');
        $nonce = $action ? $action->generateNonce() : null;

        return renderIsolate(
            REBILLY_WP_DIR . "template/front/page/{$page['template']}.php",
            compact('user', 'nonce'),
            true
        );
    }

    private function getPage(string $pageId): ?array
    {
        $pages = [
            self::PAGE_SUBSCRIPTIONS => [
                'action' => 'rebilly_subscriptions_paginate',
                'template' => 'subscriptions',
            ],
            self::PAGE_INVOICES => [
                'action' => 'rebilly_invoices_paginate',
                'template' => 'invoices',
            ],
            self::PAGE_LOGIN => [
                'template' => 'login',
            ],
        ];

        return $pages[$pageId] ?? null;
    }

    public static function getPageNames(bool $placeholder = false, string $placeholderText = 'Select Page Type'): array
    {
        $names = [
            self::PAGE_INVOICES => __('Invoices', REBILLY_WP_LANG_DOMAIN),
            self::PAGE_SUBSCRIPTIONS => __('Subscriptions', REBILLY_WP_LANG_DOMAIN),
            self::PAGE_LOGIN => __('Log-in', REBILLY_WP_LANG_DOMAIN),
        ];

        return $placeholder
            ? ['' => __($placeholderText, REBILLY_WP_LANG_DOMAIN)] + $names
            : $names;
    }
}
