<?php
/**
 * @var User $user
 * @var \Rebilly\Entities\Customer $customer
 * @var array|PaymentCard[] $cards
 * @var array|AjaxAction[] $actions
 */

use Rebilly\Entities\PaymentCard;
use Rebilly\Wp\Member\Action\AjaxAction;
use Rebilly\Wp\Member\User;

$primaryAddress = $customer->getPrimaryAddress() ?? [];

$values = [
    'first_name' => $primaryAddress['firstName'] ?? $user->user_firstname,
    'last_name' => $primaryAddress['lastName'] ?? $user->user_lastname,
    'organization' => $primaryAddress['organization'] ?? '',
    'country' => $primaryAddress['country'] ?? '',
    'region' => $primaryAddress['region'] ?? '',
    'city' => $primaryAddress['city'] ?? '',
    'address1' => $primaryAddress['address'] ?? '',
    'address2' => $primaryAddress['address2'] ?? '',
    'postalCode' => $primaryAddress['postalCode'] ?? '',
];
?>
<div class="reformer-wrap wp_rebilly_m__billing_portal__add_card_wrap">
    <form class="reformer__form wp_rebilly_m__billing_portal__add_card" method="post"
          action="<?php esc_attr_e(admin_url('admin-ajax.php')); ?>">
        <div class="wp_rebilly_m__overlay">
            <div class="wp_rebilly_m__logo">
                <div class="mr-re"></div>
                <div class="mr-bil"></div>
                <div class="mr-ly"></div>
            </div>
        </div>
        <input type="hidden" data-rebilly="token" name="rebilly-token" class="wp_rebilly_m__card_token">
        <input type="hidden" name="_form" value="5">
        <input type="hidden" name="action" value="<?php esc_attr_e($actions['add']->getName()); ?>">
        <input type="hidden" name="_nonce" value="<?php esc_attr_e($actions['add']->generateNonce()); ?>">

        <h2 class="toggle-visibility hidden" data-target="#add-card-body">Add a Payment Card</h2>
        <div id="add-card-body" class="form-body" style="display: none">
            <div class="wp_rebilly_m__message_group"></div>

            <div class="form-group">
                <label for="add-card-first_name" class="form-label">First Name</label>
                <input id="add-card-first_name" class="form-control" name="first_name"
                       value="<?php esc_attr_e($values['first_name']); ?>"
                       type="text" data-rebilly="firstName">
            </div>
            <div class="form-group">
                <label for="add-card-last_name" class="form-label">Last Name</label>
                <input id="add-card-last_name" class="form-control" name="last_name"
                       value="<?php esc_attr_e($values['last_name']); ?>"
                       type="text" data-rebilly="lastName">
            </div>
            <div class="form-group">
                <label for="add-card-organization" class="form-label">Organization</label>
                <input id="add-card-organization" class="form-control" name="organization"
                       value="<?php esc_attr_e($values['organization']); ?>"
                       type="text" data-rebilly="organization">
            </div>
            <div class="form-group">
                <label for="add-card-country" class="form-label">Country</label>
                <select id="add-card-country" class="form-control" name="country" data-rebilly="country">
                    <option value="" <?php echo $values['country'] == '' ? 'selected' : ''; ?> disabled>–Please select
                        country–
                    </option>
                    <?php foreach (wp_rebilly_m_countries() as $key => $value): ?>
                        <option
                            value="<?php esc_attr_e($key); ?>" <?php echo $values['country'] == $key ? 'selected' : ''; ?>><?php esc_html_e($value); ?></option>
                    <?php endforeach; ?>
                </select>
            </div>
            <div class="form-group">
                <label for="add-card-region" class="form-label">Region</label>
                <input id="add-card-region" class="form-control" name="region"
                       value="<?php esc_attr_e($values['region']); ?>"
                       type="text" data-rebilly="region">
            </div>
            <div class="form-group">
                <label for="add-card-city" class="form-label">City</label>
                <input id="add-card-city" class="form-control" name="city" value="<?php esc_attr_e($values['city']); ?>"
                       type="text" data-rebilly="city">
            </div>
            <div class="form-group">
                <label for="add-card-address1" class="form-label">Address Line 1</label>
                <input id="add-card-address1" class="form-control" name="address1"
                       value="<?php esc_attr_e($values['address1']); ?>"
                       type="text" data-rebilly="address">
            </div>
            <div class="form-group">
                <label for="add-card-address2" class="form-label">Address Line 2</label>
                <input id="add-card-address2" class="form-control" name="address2"
                       value="<?php esc_attr_e($values['address2']); ?>"
                       type="text" data-rebilly="address2">
            </div>
            <div class="form-group">
                <label for="add-card-postal_code" class="form-label">Postal code (ZIP)</label>
                <input id="add-card-postal_code" class="form-control" name="postal_code"
                       value="<?php esc_attr_e($values['postalCode']); ?>"
                       type="text" data-rebilly="postalCode">
            </div>

            <div class="form-group">
                <label class="form-label">Payment Card</label>
                <div class="rebilly__framepay wp_rebilly_m__payment_card">
                </div>
            </div>
            <div class="form-group">
                <button class="btn btn-block" type="submit">Save</button>
            </div>
        </div>
    </form>
</div>
