<?php
/**
 * Plugin Name: Rebilly
 * Plugin URI:  https://www.rebilly.com
 * Description: Rebilly's order form builder and content restriction plugin
 * Version:     0.2.0
 * Author:      Rebilly
 * Author URI:  https://www.rebilly.com
 * Text Domain: rebilly
 * License:     GPLv2
 */

// Exit if accessed directly.
if (!defined('ABSPATH')) {
    exit();
}

// Initialize constants.
define('REBILLY_WP_VERSION', '0.2.0');
define('REBILLY_WP_PHP_VERSION', '7.1.0');
define('REBILLY_WP_LANG_DOMAIN', 'rebilly');
define('REBILLY_WP_URL', plugin_dir_url(__FILE__));
define('REBILLY_WP_DIR', __DIR__ . '/'); // TODO use plugin_dir_path

// Initialize the plugin.
add_action('after_setup_theme', 'rebilly_init', 10);

// Install the plugin.
register_activation_hook(__FILE__, 'rebilly_install');
register_deactivation_hook(__FILE__, 'rebilly_uninstall');

/** @var \Rebilly\Wp\Member\Plugin $wp_rebilly_m */
global $wp_rebilly_m;

function rebilly_validate_requirements($intlCheck = false)
{
    if (version_compare(PHP_VERSION, REBILLY_WP_PHP_VERSION, '<')) {
        rebilly_admin_notice(
            sprintf(
                __('Rebilly requires at least PHP version 7.1, you have %s installed.', REBILLY_WP_LANG_DOMAIN),
                PHP_VERSION
            ),
            'error',
            true
        );

        return false;
    }
    if ($intlCheck && !extension_loaded('intl') && !class_exists('NumberFormatter')) {
        rebilly_admin_notice(
            sprintf(
                __('Rebilly requires PHP extension %s to be installed to operate.', REBILLY_WP_LANG_DOMAIN),
                'intl'
            ),
            'error',
            true
        );

        return false;
    }

    return true;
}

function rebilly_admin_notice($message, $type = 'success', $dismissible = false)
{
    add_action('admin_notices', function () use ($message, $type, $dismissible) {
        printf(
            '<div class="notice notice-%s %s"><p>%s</p></div>',
            $type,
            $dismissible ? 'is-dismissible' : '',
            $message
        );
    });
}

function rebilly_init()
{
    if (!rebilly_validate_requirements()) {
        return;
    }

    require_once REBILLY_WP_DIR . 'vendor/autoload.php';

    if (!rebilly_validate_requirements(true)) {
        return;
    }

    do_action('rebilly_before_init');

    global $wp_rebilly_m;
    $wp_rebilly_m = \Rebilly\Wp\Member\Plugin::instance();

    do_action('rebilly_after_init');
}

function rebilly_install()
{
    if (!rebilly_validate_requirements()) {
        return;
    }
}

function rebilly_uninstall()
{
    if (!rebilly_validate_requirements()) {
        return;
    }

    require_once REBILLY_WP_DIR . 'vendor/autoload.php';

    $wp_rebilly_m = \Rebilly\Wp\Member\Plugin::instance();
    $wp_rebilly_m->uninstall();
}
